@@ -18,7 +18,7 @@
 #' @export
 scale_fill_dra <- function(...) {
   ggplot2::discrete_scale(aesthetics = 'fill', scale_name = 'dra',
-                          palette = rot_pal(ggredist$dra), ...)
+                          palette = palette::palette_function(ggredist$dra), ...)
 }
 
 
@@ -27,7 +27,7 @@ scale_fill_dra <- function(...) {
 #' @export
 scale_color_dra <- function(...) {
   ggplot2::discrete_scale(aesthetics = 'color', scale_name = 'dra',
-                          palette = rot_pal(ggredist$dra), ...)
+                          palette = palette::palette_function(ggredist$dra), ...)
 }
 #' @rdname scale_dra
 #' @concept colors
