@@ -18,7 +18,7 @@
 #' @export
 scale_fill_penn82 <- function(...) {
   ggplot2::discrete_scale(aesthetics = 'fill', scale_name = 'penn82',
-                          palette = rot_pal(ggredist$penn82), ...)
+                          palette = palette::palette_function(ggredist$penn82), ...)
 }
 
 #' @rdname scale_penn82
@@ -26,7 +26,7 @@ scale_fill_penn82 <- function(...) {
 #' @export
 scale_color_penn82 <- function(...) {
   ggplot2::discrete_scale(aesthetics = 'color', scale_name = 'penn82',
-                          palette = rot_pal(ggredist$penn82), ...)
+                          palette = palette::palette_function(ggredist$penn82), ...)
 }
 #' @rdname scale_penn82
 #' @concept colors
